imageAsset property
Optional asset image path to display in the tooltip card.
If provided, an image will be loaded from the app's assets and displayed above the description.
imageAsset: 'assets/images/guide.png'
Implementation
final String? imageAsset;