imageUrl property
Optional network image URL to display in the tooltip card.
If provided, an image will be loaded from this URL and displayed above the description. This is useful for showing screenshots or visual guides.
imageUrl: 'https://example.com/screenshot.png'
Implementation
final String? imageUrl;